# kdui2py
将qt的UI文件批量转换成python文件。

batch convert qt ui file to python file, or convert single ui file, or convert ui files in a folder include it's subfolder.

 # 截图

![截图](/screenshot/screen-2019-04-06-11-11-26.png.png) 

 # 安装

## 方法一

– 使用[kdPythonInstaller(https://github.com/bkdwei/kdPythonInstaller/releases/download/v1.0.0/kdPythonInstaller-1.0.0.exe/) 快速安装python和kdui2py



## 方法二

– 安装python3和pip，[安装包地址](https://www.python.org/downloads/)

– 使用pip安装kdui2py，命令

> pip install kdui2py